import { DesignTokens, DesignToken, DesignTokensPaths } from '#design-tokens/types';
import * as CSSType from 'csstype';
import { Core } from 'browser-style-dictionary/types/browser';
import { Dictionary } from 'browser-style-dictionary/types/Dictionary';

declare const palette: (color: string, suffixes?: Array<string | number>, padding?: number) => DesignTokens;

interface CSSProperties extends CSSType.StandardProperties, CSSType.StandardShorthandProperties, CSSType.StandardProperties, CSSType.SvgProperties {
}
/**
 * Properties to be used in `compose({ ...properties })`
 */
declare type Properties = {
    [key in keyof CSSProperties]?: CSSProperties[key];
};
/**
 * Pseudos to be used in `compose({ ':pseudo': { ...} })`
 */
declare type Pseudos = {
    [key in CSSType.Pseudos]?: Properties;
};
declare type Variants = {
    [key: string]: Properties & Pseudos;
};
interface Compose extends Properties, Pseudos {
    variants: Variants;
}
/**
 * Compose a CSS style declaration from a type-safe JS object.
 *
 * Supports pseudo and nested selectors.
 */
declare const compose: (properties: Compose) => {
    composed: boolean;
};

declare const stubTokens: (buildPath: string, force?: boolean) => Promise<void>;
declare const getStyleDictionaryInstance: (tokens: NuxtDesignTokens, buildPath: string) => Promise<Core>;
declare const generateTokens: (tokens: NuxtDesignTokens, buildPath: string, silent?: boolean) => Promise<Dictionary>;

interface GlobalTokens {
    /**
     * Standard way to define your color palette.
     */
    colors: DesignTokens;
    /**
     * Standard screen sizes commonly used.
     */
    screens: {
        '2xs': DesignToken;
        xs: DesignToken;
        sm: DesignToken;
        md: DesignToken;
        lg: DesignToken;
        xl: DesignToken;
        '2xl': DesignToken;
        '3xl': DesignToken;
    } & DesignTokens;
}
interface NuxtDesignTokens extends DesignTokens, GlobalTokens {
}
interface NuxtDesignTokensConfig {
    server?: boolean;
    tokens?: NuxtDesignTokens | boolean | string;
}
interface ModuleOptions extends NuxtDesignTokensConfig {
}
interface ModuleHooks {
}
interface ModulePublicRuntimeConfig {
}
interface ModulePrivateRuntimeConfig {
    tokensDir?: string;
    server?: boolean;
    tokensFilePaths?: Array<string>;
}
declare type DeepPartial<T> = T extends object ? {
    [P in keyof T]?: DeepPartial<T[P]>;
} : T;

declare const defineTokens: (tokens: DeepPartial<NuxtDesignTokens>) => DeepPartial<NuxtDesignTokens>;
declare const $tokens: (path: DesignTokensPaths, { key, flatten }: {
    key?: keyof DesignToken;
    flatten?: boolean;
}) => any;
declare const $dt: (path: DesignTokensPaths, { key, flatten }: {
    key?: keyof DesignToken;
    flatten?: boolean;
}) => any;
declare module '@nuxt/schema' {
    interface PublicRuntimeConfig {
        designTokens?: ModulePublicRuntimeConfig;
    }
    interface RuntimeConfig {
        designTokens?: ModulePrivateRuntimeConfig;
    }
    interface NuxtConfig {
        designTokens?: Partial<ModuleOptions>;
    }
    interface NuxtOptions {
        designTokens?: ModuleOptions;
    }
}

export { $tokens as $, DeepPartial as D, GlobalTokens as G, ModuleOptions as M, NuxtDesignTokens as N, generateTokens as a, NuxtDesignTokensConfig as b, compose as c, ModuleHooks as d, ModulePublicRuntimeConfig as e, ModulePrivateRuntimeConfig as f, getStyleDictionaryInstance as g, defineTokens as h, $dt as i, palette as p, stubTokens as s };
